# -*- coding: utf-8 -*-

"""
whid: What Have I Done?
:copyright: (c) 2021 akihakune
:license: MIT, see LICENSE for more details.
"""

__title__ = 'whid'
__author__ = 'akihakune'
__author_email__ = 'akihakune@gmail.com'
__license__ = 'MIT'
__description__ = 'What Have I Done? - Review things you have done on your desktop.'
__url__ = 'https://github.com/git-akihakune/whid'
__copyright__ = 'Copyright (c) 2021 akihakune'
__version__ = '0.1.2'